fix_topIsLow_yarp-3.4 {#yarp_3_4}
---------------------

## Libraries

### `sig`

#### `Image`

* Fixed compatibility with images with topIsLow==false sent by YARP 3.5.


## GUIs

### `yarpview`

* Fixed upside down image when topIsLow is false (Qt >= 5.3.2 only).
